@@ -40,6 +40,8 @@ def replace_date_funcs(node: exp.Expression) -> exp.Expression:
         isinstance(node, (exp.Date, exp.TsOrDsToDate))
         and not node.expressions
         and not node.args.get("zone")
+        and node.this.is_string
+        and is_iso_date(node.this.name)
     ):
         return exp.cast(node.this, to=exp.DataType.Type.DATE)
     if isinstance(node, exp.Timestamp) and not node.args.get("zone"):
@@ -90,6 +92,12 @@ def remove_redundant_casts(expression: exp.Expression) -> exp.Expression:
         and expression.to.this == expression.this.type.this
     ):
         return expression.this
+    if (
+        isinstance(expression, (exp.Date, exp.TsOrDsToDate))
+        and expression.this.type
+        and expression.this.type.this == exp.DataType.Type.DATE
+    ):
+        return expression.this
     return expression
 
 
