@@ -213,6 +213,12 @@ class TestRedshift(Validator):
                 "redshift": "SELECT CAST('abc' AS VARBYTE)",
             },
         )
+        self.validate_all(
+            "CREATE TABLE a (b BINARY VARYING(10))",
+            write={
+                "redshift": "CREATE TABLE a (b VARBYTE(10))",
+            },
+        )
         self.validate_all(
             "SELECT 'abc'::CHARACTER",
             write={
